Enum csv_perusal::CSVType
source · pub enum CSVType {
Int(i64),
Float(f64),
String(String),
Date(NaiveDate),
Time(NaiveTime),
DateTime(NaiveDateTime),
Error(CellError),
Empty,
}Expand description
CSVType is the organized the data from csv::ByteRecord.
It’s meant to make the generic output data from the csv package easier to work with by giving each cell a specific data type.
Date, Time, and DateTime use chrono’s chrono::NaiveDate, chrono::NaiveTime, and chrono::NaiveDateTime respectively.
Variants
Int(i64)
Float(f64)
String(String)
Date(NaiveDate)
Time(NaiveTime)
DateTime(NaiveDateTime)
Error(CellError)
Empty